@@ -1,10 +1,12 @@
+from credmgr.models.utils import CachedProperty
+
 
 class OwnerMixin:
     _editableAttrs = []
 
-    @property
+    @CachedProperty
     def owner(self):
-        if self.ownerId is None:
-            self.fetch()
+        if not self._fetched:
+            self._fetch()
         user = self._credmgr.user(id=self.ownerId)
         return user
\ No newline at end of file
