@@ -8,25 +8,30 @@ class SentryToken(BaseApp):
     _path = '/sentry_tokens'
     _credmgrCallable = 'sentryToken'
 
-    def __init__(self, credmgr, id=None, appName=None, dsn=None, enabled=None, ownerId=None):
-        super().__init__(credmgr, id, appName, enabled, ownerId)
-        self.dsn = dsn
+    def __init__(self, credmgr, **kwargs):
+        '''Initialize a Sentry Token instance.
+
+        :param credmgr: An instance of :class:`~.CredentialManager`.
+        :param id: ID of the Sentry Token
+        :param str name: Name of the Sentry Token.
+        :param str dsn: Sentry DSN url for reporting errors.
+        :param ownerId: ID of the `~.User` that owns this Sentry Token.
+        '''
+        super().__init__(credmgr, **kwargs)
 
     @staticmethod
     @resolveUser()
-    def _create(_credmgr, appName=None, dsn=None, owner=None):
+    def _create(_credmgr, name=None, dsn=None, owner=None):
         '''Create a new Sentry Token
 
-        **PERMISSIONS: At least Active user is required.**
-
         Sentry Tokens are used for logging and error reporting in applications
 
-        :param str appName: Name of the Sentry Token (required)
+        :param str name: Name of the Sentry Token (required)
         :param str dsn: DSN of the Sentry Token (required)
         :param Union[User,int,str] owner: Owner of the verification. Requires Admin to create for other users.
         :return: SentryToken
         '''
-        data = {'app_name': appName, 'dsn': dsn}
+        data = {'app_name': name, 'dsn': dsn}
         if owner:
             data['owner_id'] = owner
         return _credmgr.post('/sentry_tokens', data=data)
\ No newline at end of file
